==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfile.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILE_H
#define BIBTEXFILE_H

#include <qobject.h>
#include <qvaluelist.h>

class QDir;
class QString;
class QChar;
class QStringList;
class QWaitCondition;
class QProcess;
class QIODevice;

namespace BibTeX
{
    class BibTeXElement;
    class BibTeXEntry;
    class BibTeXString;
    class BibTeXFileExporter;

    static const QString Months[] =
        {
            QString( "January" ), QString( "February" ), QString( "March" ), QString( "April" ), QString( "May" ), QString( "June" ), QString( "July" ), QString( "August" ), QString( "September" ), QString( "October" ), QString( "November" ), QString( "December" )
        };

    static const QString MonthsTriple[] =
        {
            QString( "jan" ), QString( "feb" ), QString( "mar" ), QString( "apr" ), QString( "may" ), QString( "jun" ), QString( "jul" ), QString( "aug" ), QString( "sep" ), QString( "oct" ), QString( "nov" ), QString( "dec" )
        };

    class BibTeXFile : public QObject
    {
        Q_OBJECT

        friend class BibTeXFileExporterXML;
        friend class BibTeXFileExporterBibTeX;
        friend class BibTeXFileExporter;
        friend class BibTeXFileParser;

    public:
        enum Encoding {encImplicit = 0, encLaTeX = 1, encUTF8 = 2};
        enum StringProtection { spNone, spParanthesis, spQuote, spBoth };

        BibTeXFile( );
        ~BibTeXFile();

        unsigned int count ();
        BibTeXElement* at( const unsigned int index );
        void append( BibTeXFile *other );
        void appendElement( BibTeXElement *element );
        void deleteElement( BibTeXElement *element );

        QString preamble();
        void setPreamble( const QString &preamble );

        void insert( BibTeXFile *bibtexfile );

        BibTeXElement *containsKey( const QString &key );

    protected:
        typedef QValueList<BibTeXElement*> ElementList;
        ElementList elements;
        QString m_preamble;

    private:
        void clearElements();

        //     private slots:
        //         void slotProgress( int current, int total );

    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfile.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILE_H
#define BIBTEXFILE_H

#include <qobject.h>
#include <qvaluelist.h>

class QDir;
class QString;
class QChar;
class QStringList;
class QWaitCondition;
class QProcess;
class QIODevice;

namespace BibTeX
{
    class BibTeXElement;
    class BibTeXEntry;
    class BibTeXString;
    class BibTeXFileExporter;

    static const QString Months[] =
        {
            QString( "January" ), QString( "February" ), QString( "March" ), QString( "April" ), QString( "May" ), QString( "June" ), QString( "July" ), QString( "August" ), QString( "September" ), QString( "October" ), QString( "November" ), QString( "December" )
        };

    static const QString MonthsTriple[] =
        {
            QString( "jan" ), QString( "feb" ), QString( "mar" ), QString( "apr" ), QString( "may" ), QString( "jun" ), QString( "jul" ), QString( "aug" ), QString( "sep" ), QString( "oct" ), QString( "nov" ), QString( "dec" )
        };

    class BibTeXFile : public QObject
    {
        Q_OBJECT

        friend class BibTeXFileExporterXML;
        friend class BibTeXFileExporterBibTeX;
        friend class BibTeXFileExporter;
        friend class BibTeXFileParser;

    public:
        enum Encoding {encImplicit = 0, encLaTeX = 1, encUTF8 = 2};
        enum StringProtection { spNone, spParanthesis, spQuote, spBoth };

        BibTeXFile( );
        ~BibTeXFile();

        unsigned int count ();
        BibTeXElement* at( const unsigned int index );
        void append( BibTeXFile *other, BibTeXElement *before = NULL );
        void appendElement( BibTeXElement *element );
        void deleteElement( BibTeXElement *element );

        QString preamble();
        void setPreamble( const QString &preamble );

        //         void insert( BibTeXFile *bibtexfile );

        BibTeXElement *containsKey( const QString &key );

    protected:
        typedef QValueList<BibTeXElement*> ElementList;
        ElementList elements;
        QString m_preamble;

    private:
        void clearElements();
        void appendElement( BibTeXElement *element, ElementList::iterator& it );

        //     private slots:
        //         void slotProgress( int current, int total );

    };

}

#endif
